==> egg-foundation-1.0.0-20210908.020113-5-sources.jar: com/bxm/egg/common/url/TopicProtocolBuilder.java <==
package com.bxm.egg.common.url;

import com.bxm.egg.common.constant.AppConst;
import com.bxm.foundation.base.facade.enums.DomainScene;
import com.bxm.foundation.base.facade.enums.DomainViewScene;
import com.bxm.foundation.base.facade.param.DomainFetchParam;
import com.bxm.foundation.base.facade.service.DomainFacadeService;

/**
 * 话题协议跳转
 *
 * @author liujia
 * @date 1/20/21 5:06 PM
 **/
public class TopicProtocolBuilder extends AbstractProtocolBuilder {

    TopicProtocolBuilder(DomainFacadeService domainIntegrationService) {
        super(domainIntegrationService);
    }

    /**
     * 构建站外分享地址
     */
    public OuterProtocolBuilder outer() {
        return new OuterProtocolBuilder();
    }

    /**
     * 构建站内访问协议地址
     */
    public AppProtocolBuilder app() {
        return new AppProtocolBuilder();
    }

    public class OuterProtocolBuilder {

        private Long topicId;

        private Long userId;

        private String areaCode;

        private String areaName;

        public OuterProtocolBuilder userId(Long userId) {
            this.userId = userId;
            return this;
        }

        public OuterProtocolBuilder topicId(Long topicId) {
            this.topicId = topicId;
            return this;
        }

        public OuterProtocolBuilder areaCode(String areaCode) {
            this.areaCode = areaCode;
            return this;
        }

        public OuterProtocolBuilder areaName(String areaName) {
            this.areaName = areaName;
            return this;
        }

        public String build() {
            String baseUrl = domainIntegrationService.getBaseUrlInfo(DomainFetchParam.builder()
                    .srcApp(AppConst.SRC_APP)
                    .scene(DomainScene.OUTSIDE_SHARE)
                    .viewScene(DomainViewScene.CONTENT_VIEW)
                    .build());

            StringBuilder url = new StringBuilder();
            url.append(baseUrl);
            url.append("/shareTopicDetail.html");
            url.append("?id=").append(topicId);

            if (null != userId) {
                url.append("&userId=").append(userId);
            }
            if (null != areaCode) {
                url.append("&areaCode=").append(areaCode);
            }
            if (null != areaName) {
                url.append("&areaName=").append(encode(areaName));
            }

            return url.toString();
        }
    }

    public class AppProtocolBuilder {
        private Long topicId;

        public AppProtocolBuilder topicId(Long topicId) {
            this.topicId = topicId;
            return this;
        }

        public String build() {
            return "wst://community/topicDetail?tp=topic&topicId=" + topicId + "";
        }
    }
}

==> egg-foundation-1.0.0-20211014.145001-23-sources.jar: com/bxm/egg/common/url/TopicProtocolBuilder.java <==
package com.bxm.egg.common.url;

import com.bxm.egg.common.constant.AppConst;
import com.bxm.foundation.base.facade.enums.DomainScene;
import com.bxm.foundation.base.facade.enums.DomainViewScene;
import com.bxm.foundation.base.facade.param.DomainFetchParam;
import com.bxm.foundation.base.facade.service.DomainFacadeService;

/**
 * 话题协议跳转
 *
 * @author liujia
 * @date 1/20/21 5:06 PM
 **/
public class TopicProtocolBuilder extends AbstractProtocolBuilder {

    TopicProtocolBuilder(DomainFacadeService domainIntegrationService) {
        super(domainIntegrationService);
    }

    /**
     * 构建站外分享地址
     */
    public OuterProtocolBuilder outer() {
        return new OuterProtocolBuilder();
    }

    /**
     * 构建站内访问协议地址
     */
    public AppProtocolBuilder app() {
        return new AppProtocolBuilder();
    }

    public class OuterProtocolBuilder {

        private Long topicId;

        private Long userId;

        private String areaCode;

        private String areaName;

        public OuterProtocolBuilder userId(Long userId) {
            this.userId = userId;
            return this;
        }

        public OuterProtocolBuilder topicId(Long topicId) {
            this.topicId = topicId;
            return this;
        }

        public OuterProtocolBuilder areaCode(String areaCode) {
            this.areaCode = areaCode;
            return this;
        }

        public OuterProtocolBuilder areaName(String areaName) {
            this.areaName = areaName;
            return this;
        }

        public String build() {
            String baseUrl = domainIntegrationService.getBaseUrlInfo(DomainFetchParam.builder()
                    .srcApp(AppConst.SRC_APP)
                    .scene(DomainScene.OUTSIDE_SHARE)
                    .viewScene(DomainViewScene.CONTENT_VIEW)
                    .build());

            StringBuilder url = new StringBuilder();
            url.append(baseUrl);
            url.append("/shareTopicDetail.html");
            url.append("?id=").append(topicId);

            if (null != userId) {
                url.append("&userId=").append(userId);
            }
            if (null != areaCode) {
                url.append("&areaCode=").append(areaCode);
            }
            if (null != areaName) {
                url.append("&areaName=").append(encode(areaName));
            }

            return url.toString();
        }
    }

    public class AppProtocolBuilder {
        private Long topicId;

        public AppProtocolBuilder topicId(Long topicId) {
            this.topicId = topicId;
            return this;
        }

        public String build() {
            return "egg://community/topicDetail?tp=topic&topicId=" + topicId + "";
        }
    }
}
